/*  $Id: input_context.h,v 1.15 2003/07/20 22:38:12 grumbel Exp $
**
**  ClanLib Game SDK
**  Copyright (C) 2003  The ClanLib Team
**  For a total list of contributers see the file CREDITS.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Lesser General Public License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
**
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_input_context
#define header_input_context

#include "../signals.h"

class CL_InputDevice;
class CL_InputEvent;
class CL_InputContext_Generic;

//: Input events interface.
//- <p>An input context is a collection of inputdevices available in
//- a displaywindow.</p>
class CL_InputContext
{
//! Construction:
public:
	//: Constructs an input context.
	//param num_keyboards: Number of keyboards to be associated with this input context.
	//param num_mice: Number of mice to be associated with this input context.
	//param num_joysticks: Number of joysticks to be associated with the input context.
	CL_InputContext(
		int num_keyboards,
		int num_mice,
		int num_joysticks);

	~CL_InputContext();

//! Attributes:
public:
	//: Returns the number of keyboards available.
	int get_keyboard_count() const;

	//: Returns the number of mice available.
	int get_mouse_count() const;

	//: Returns the number of joysticks available.
	int get_joystick_count() const;

	//: Returns the input device for the specified keyboard.
	CL_InputDevice &get_keyboard(int keyboard = 0);

	//: Returns the input device for the specified mouse.
	CL_InputDevice &get_mouse(int mouse = 0);

	//: Returns the input device for the specified joystick.
	CL_InputDevice &get_joystick(int joystick = 0);

//! Operations:
public:

//! Implementation:
private:
	CL_InputContext_Generic *impl;
};

#endif
